@@ -6,6 +6,7 @@ mod error;
 mod error_merger;
 mod format;
 mod generate_rust;
+mod generate_typescript;
 mod identifier;
 mod parser;
 mod schema;
@@ -41,7 +42,8 @@ const BIN_NAME: &str = "typical";
 // Command-line option and subcommand names
 const GENERATE_SUBCOMMAND: &str = "generate";
 const GENERATE_SUBCOMMAND_PATH_OPTION: &str = "generate-path";
-const GENERATE_SUBCOMMAND_RUST_OUT_FILE_OPTION: &str = "rust-out-file";
+const GENERATE_SUBCOMMAND_RUST_OUT_FILE_OPTION: &str = "rust-out";
+const GENERATE_SUBCOMMAND_TYPESCRIPT_OUT_FILE_OPTION: &str = "typescript-out";
 const SHELL_COMPLETION_SUBCOMMAND: &str = "shell-completion";
 const SHELL_COMPLETION_SUBCOMMAND_SHELL_OPTION: &str = "shell-completion-shell";
 
@@ -71,6 +73,12 @@ fn cli<'a, 'b>() -> App<'a, 'b> {
                         .value_name("PATH")
                         .long(GENERATE_SUBCOMMAND_RUST_OUT_FILE_OPTION)
                         .help("Sets the path of the Rust file to emit"),
+                )
+                .arg(
+                    Arg::with_name(GENERATE_SUBCOMMAND_TYPESCRIPT_OUT_FILE_OPTION)
+                        .value_name("PATH")
+                        .long(GENERATE_SUBCOMMAND_TYPESCRIPT_OUT_FILE_OPTION)
+                        .help("Sets the path of the TypeScript file to emit"),
                 ),
         )
         .subcommand(
@@ -92,7 +100,11 @@ fn cli<'a, 'b>() -> App<'a, 'b> {
 }
 
 // Generate code for a schema and its transitive dependencies
-fn generate_code(schema_path: &Path, rust_out_file: Option<&Path>) -> Result<(), Error> {
+fn generate_code(
+    schema_path: &Path,
+    rust_out: Option<&Path>,
+    typescript_out: Option<&Path>,
+) -> Result<(), Error> {
     // Load the schema and its transitive dependencies.
     eprintln!("Loading schemas\u{2026}");
     let schemas = load_schemas(schema_path).map_err(|errors| merge_errors(&errors))?;
@@ -103,11 +115,39 @@ fn generate_code(schema_path: &Path, rust_out_file: Option<&Path>) -> Result<(),
     validate(&schemas).map_err(|errors| merge_errors(&errors))?;
 
     // Generate Rust code, if applicable.
-    if let Some(rust_out_file) = rust_out_file {
+    if let Some(rust_out) = rust_out {
         eprintln!("Generating Rust\u{2026}");
 
         // Create any missing intermediate directories as needed.
-        if let Some(parent) = rust_out_file.parent() {
+        if let Some(parent) = rust_out.parent() {
+            create_dir_all(parent).map_err(|error| {
+                throw(
+                    &format!("Unable to create {}.", parent.to_string_lossy().code_str()),
+                    None,
+                    None,
+                    Some(error),
+                )
+            })?;
+        }
+
+        // Generate the code and write it to the file.
+        eprintln!("Writing {}\u{2026}", rust_out.to_string_lossy().code_str());
+        write(rust_out, generate_rust::generate(VERSION, &schemas)).map_err(|error| {
+            throw(
+                &format!("Unable to write {}.", rust_out.to_string_lossy().code_str()),
+                None,
+                None,
+                Some(error),
+            )
+        })?;
+    }
+
+    // Generate TypeScript code, if applicable.
+    if let Some(typescript_out) = typescript_out {
+        eprintln!("Generating Rust\u{2026}");
+
+        // Create any missing intermediate directories as needed.
+        if let Some(parent) = typescript_out.parent() {
             create_dir_all(parent).map_err(|error| {
                 throw(
                     &format!("Unable to create {}.", parent.to_string_lossy().code_str()),
@@ -121,13 +161,17 @@ fn generate_code(schema_path: &Path, rust_out_file: Option<&Path>) -> Result<(),
         // Generate the code and write it to the file.
         eprintln!(
             "Writing {}\u{2026}",
-            rust_out_file.to_string_lossy().code_str(),
+            typescript_out.to_string_lossy().code_str(),
         );
-        write(rust_out_file, generate_rust::generate(VERSION, schemas)).map_err(|error| {
+        write(
+            typescript_out,
+            generate_typescript::generate(VERSION, &schemas),
+        )
+        .map_err(|error| {
             throw(
                 &format!(
                     "Unable to write {}.",
-                    rust_out_file.to_string_lossy().code_str(),
+                    typescript_out.to_string_lossy().code_str(),
                 ),
                 None,
                 None,
@@ -187,14 +231,21 @@ fn entry() -> Result<(), Error> {
             );
 
             // Determine the path to the Rust output file, if provided.
-            let rust_out_file = matches
+            let rust_out = matches
                 .subcommand_matches(GENERATE_SUBCOMMAND)
                 .unwrap() // [ref:generate_subcommand]
                 .value_of(GENERATE_SUBCOMMAND_RUST_OUT_FILE_OPTION)
                 .map(Path::new);
 
+            // Determine the path to the TypeScript output file, if provided.
+            let typescript_out = matches
+                .subcommand_matches(GENERATE_SUBCOMMAND)
+                .unwrap() // [ref:generate_subcommand]
+                .value_of(GENERATE_SUBCOMMAND_TYPESCRIPT_OUT_FILE_OPTION)
+                .map(Path::new);
+
             // Generate code for the schema.
-            generate_code(schema_path, rust_out_file)?;
+            generate_code(schema_path, rust_out, typescript_out)?;
         }
 
         // [tag:shell_completion_subcommand]
